"""
confirmemail feature configuration.

Auto-generated by `splent feature:inject-config`.
Injects environment variables into Flask app.config.
"""

import os


def inject_config(app):
    app.config.update({
        "CONFIRM_EMAIL_SALT": os.getenv("CONFIRM_EMAIL_SALT", "sample_salt"),
        "CONFIRM_EMAIL_TOKEN_MAX_AGE": int(os.getenv("CONFIRM_EMAIL_TOKEN_MAX_AGE", "3600")),
    })
